@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2014-2018 Laurent Montel <montel@kde.org>
+ * Copyright (C) 2014-2019 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,7 +16,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -53,10 +53,10 @@ CalendarIndexer::~CalendarIndexer()
 
 QStringList CalendarIndexer::mimeTypes() const
 {
-    return QStringList() << QString::fromLatin1("application/x-vnd.akonadi.calendar.event")
-           << QString::fromLatin1("application/x-vnd.akonadi.calendar.todo")
-           << QString::fromLatin1("application/x-vnd.akonadi.calendar.journal")
-           << QString::fromLatin1("application/x-vnd.akonadi.calendar.freebusy");
+    return QStringList() << QStringLiteral("application/x-vnd.akonadi.calendar.event")
+           << QStringLiteral("application/x-vnd.akonadi.calendar.todo")
+           << QStringLiteral("application/x-vnd.akonadi.calendar.journal")
+           << QStringLiteral("application/x-vnd.akonadi.calendar.freebusy");
 }
 
 void CalendarIndexer::index(const Akonadi::Item &item)
